leaftools.leaf_to_augmented_tuplet_with_n_notes_of_equal_written_duration
=========================================================================

.. autofunction:: abjad.tools.leaftools.leaf_to_augmented_tuplet_with_n_notes_of_equal_written_duration.leaf_to_augmented_tuplet_with_n_notes_of_equal_written_duration
